about summary refs log tree commit diff
path: root/nixpkgs/pkgs/applications/editors/aseprite/skia.nix
diff options
context:
space:
mode:
Diffstat (limited to 'nixpkgs/pkgs/applications/editors/aseprite/skia.nix')
-rw-r--r--nixpkgs/pkgs/applications/editors/aseprite/skia.nix31
1 files changed, 13 insertions, 18 deletions
diff --git a/nixpkgs/pkgs/applications/editors/aseprite/skia.nix b/nixpkgs/pkgs/applications/editors/aseprite/skia.nix
index 2de61c7e20f1..71fa62157d8a 100644
--- a/nixpkgs/pkgs/applications/editors/aseprite/skia.nix
+++ b/nixpkgs/pkgs/applications/editors/aseprite/skia.nix
@@ -1,37 +1,29 @@
-{ stdenv, lib, fetchFromGitHub, fetchgit, python2, gn, ninja
+{ stdenv, lib, fetchFromGitHub, fetchgit, python3, gn, ninja
 , fontconfig, expat, icu58, libglvnd, libjpeg, libpng, libwebp, zlib
-, mesa, libX11
+, mesa, libX11, harfbuzzFull
 }:
 
 let
   # skia-deps.nix is generated by: ./skia-make-deps.sh 'angle2|dng_sdk|piex|sfntly'
   depSrcs = import ./skia-deps.nix { inherit fetchgit; };
-  gnOld = gn.overrideAttrs (oldAttrs: rec {
-    version = "20190403";
-    src = fetchgit {
-      url = "https://gn.googlesource.com/gn";
-      rev = "64b846c96daeb3eaf08e26d8a84d8451c6cb712b";
-      sha256 = "1v2kzsshhxn0ck6gd5w16gi2m3higwd9vkyylmsczxfxnw8skgpy";
-    };
-  });
 in
 stdenv.mkDerivation {
   pname = "skia";
-  version = "aseprite-m71";
+  version = "aseprite-m102";
 
   src = fetchFromGitHub {
     owner = "aseprite";
     repo = "skia";
-    # latest commit from aseprite-m71 branch
-    rev = "89e4ca4352d05adc892f5983b108433f29b2c0c2"; # TODO: Remove the gnOld override
-    sha256 = "0n3vrkswvi6rib9zv2pzi18h3j5wm7flmgkgaikcm6q7iw4l2c7x";
+    # latest commit from aseprite-m102 branch
+    rev = "861e4743af6d9bf6077ae6dda7274e5a136ee4e2";
+    hash = "sha256-IlZbalmHl549uDUfPG8hlzub8TLWhG0EsV6HVAPdsl0=";
   };
 
-  nativeBuildInputs = [ python2 gnOld ninja ];
+  nativeBuildInputs = [ python3 gn ninja ];
 
   buildInputs = [
     fontconfig expat icu58 libglvnd libjpeg libpng libwebp zlib
-    mesa libX11
+    mesa libX11 harfbuzzFull
   ];
 
   preConfigure = with depSrcs; ''
@@ -44,13 +36,13 @@ stdenv.mkDerivation {
 
   configurePhase = ''
     runHook preConfigure
-    gn gen out/Release --args="is_debug=false is_official_build=true"
+    gn gen out/Release --args="is_debug=false is_official_build=true extra_cflags=[\"-I${harfbuzzFull.dev}/include/harfbuzz\"]"
     runHook postConfigure
   '';
 
   buildPhase = ''
     runHook preBuild
-    ninja -C out/Release skia
+    ninja -C out/Release skia modules
     runHook postBuild
   '';
 
@@ -69,8 +61,11 @@ stdenv.mkDerivation {
       include/gpu \
       include/private \
       include/utils \
+      include/third_party/skcms/*.h \
       out/Release/*.a \
       src/gpu/**/*.h \
+      src/core/*.h \
+      modules/skshaper/include/*.h \
       third_party/externals/angle2/include \
       third_party/skcms/**/*.h
   '';